@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '2.004003'; # VERSION
+our $VERSION = '2.004004'; # VERSION
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -131,7 +131,7 @@ Dist::Zilla::Plugin::Test::PodSpelling - Author tests for POD spelling
 
 =head1 VERSION
 
-version 2.004003
+version 2.004004
 
 =head1 SYNOPSIS
 
@@ -220,7 +220,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =item *
 
-Randy Stauner <randy@magnificent-tears.com>
+Randy Stauner <rwstauner@cpan.org>
 
 =item *
 
